You are viewing a plain text version of this content. The canonical link for it is here.
Posted to users@subversion.apache.org by Jacob Weber <ja...@jacobweber.com> on 2009/10/18 05:47:01 UTC

Merge with --ignore-ancestry is extremely slow

Hello. I'm trying to mergee two branches that were imported from CVS, so I'm using --ignore-ancestry. The merge works correctly, but it takes about 50 minutes. Is this normal? Is there a faster alternative?

The project contains about 9000 files. There are only about 12 differences. The client is SVN 1.6.5 on Mac OS 10.6.1. The server is SVN 1.6.5 on Linux, using an https Apache server with path-based authorization turned off.

Sample:

$ cd trunkDir
$ time svn merge --ignore-ancestry trunkURL branchURL

real	49m12.364s
user	0m13.301s
sys	0m12.584s

------------------------------------------------------
http://subversion.tigris.org/ds/viewMessage.do?dsForumId=1065&dsMessageId=2408621

To unsubscribe from this discussion, e-mail: [users-unsubscribe@subversion.tigris.org].